@@ -360,12 +360,6 @@ gc_zoom_to_fit_cb (GtkObject *source, gpointer data)
 	gpdf_control_zoom_fit (GPDF_CONTROL (data));
 }
 
-static void
-gc_zoom_to_fit_width_cb (GtkObject *source, gpointer data)
-{
-	gpdf_control_zoom_fit_width (GPDF_CONTROL (data));
-}
-
 static void
 gc_zoom_to_default_cb (GtkObject *source, gpointer data)
 {
@@ -478,7 +472,6 @@ gc_ui_set_pixbufs (GPdfControl *control)
 	GtkIconSet *icon_set;
 	GdkPixbuf *pixbuf, *menu_pixbuf;
 	gchar *pixbuf_xml, *menu_pixbuf_xml;
-	gint menu_width, menu_height;
 
 	gpdf_view = control->priv->gpdf_view;
 
